@@ -9,4 +9,8 @@ from pants.contrib.go.targets.go_local_source import GoLocalSource
 
 
 class GoBinary(GoLocalSource):
-  pass
+  """A local Go main package."""
+
+  @classmethod
+  def alias(cls):
+    return 'go_binary'
