@@ -9,4 +9,8 @@ from pants.contrib.go.targets.go_local_source import GoLocalSource
 
 
 class GoLibrary(GoLocalSource):
-  pass
+  """A local Go package."""
+
+  @classmethod
+  def alias(cls):
+    return 'go_library'
